<?php
// v 3.80
//PJC 11-JUN-2020 - Add apache2 logs for  Manager User
//PJC 12-APR-2019 - Added Gatekeeper
//PJC 06-DEC-2016 - Additional Logs
//PJC 03-NOV-2014 - S8000 updates
//PJC 21102014 - reset link
//PJC 10072013

session_start();
$page_id = "044";
include "/SpliceCom/WebManager/assist/.access.php";
$reset = "/SpliceCom/Web/download/reset.txt";

$manager_user = ($_SERVER['PHP_AUTH_USER']);
$script=$_SERVER['SCRIPT_NAME'];
include "/SpliceCom/WebManager/assist/tzone.php"; // include timezone

if (isset($_REQUEST['clear'])&& $_REQUEST['clear']==1) {
	if ($handle = opendir("/SpliceCom/Web/download")) {
  while (false !== ($file = readdir($handle))) {
    if ($file[0] == '.' || is_dir("/SpliceCom/Web/download/".$file)) {
       continue;
    }
    if (strtolower(substr($file,-5,5))=='.wlog') unlink("/SpliceCom/Web/download/".$file);
  }
  closedir($handle);
	}
}

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
    "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
<title>Logging - View Live System Logs</title>
<META HTTP-EQUIV="Expires" CONTENT="0">
<META HTTP-EQUIV="Pragma" CONTENT="no-cache">
<META HTTP-EQUIV="Cache-Control" CONTENT="no-cache">
<meta http-equiv="Content-type" content="text/html; charset=UTF-8"/>
<link href="/manager/assist/css/Styles.css" rel="stylesheet" type="text/css">
<link href="alert.css" rel="stylesheet" type="text/css">
<style type="text/css">
body, html, #contain {
    height: 100%;
}
#contain {
	width: 70%;
}
#maincontainer {
width: 1000px; /*Width of main container*/
margin: 0 auto; /*Center container on page*/
}
#contentwrapper {
float: left;
width: 100%;
}
#contentcolumn {
margin: 0 333px 0 333px; /*Margins for content column. Should be "0 RightColumnWidth 0 LeftColumnWidth*/
}
#leftcolumn {
float: left;
width: 333px; /*Width of left column in pixel*/
margin-left: -1000px; /*Set margin to that of -(MainContainerWidth)*/
}
#rightcolumn {
float: left;
width: 333px; /*Width of right column*/
margin-left: -333px; /*Set left margin to -(RightColumnWidth)*/
}
.innertube {
margin: 10px; /*Margins for inner DIV inside each column (to provide padding)*/
margin-top: 0;
}

div.block { overflow:hidden; }
div.block label { width:160px; display:block; float:left; text-align:left; }
div.block .input{ margin-left:4px; float:left; }
</style>
<script language="javascript">
var popupWindow = null;
function centeredPopup(url,winName,w,h,scroll){
LeftPosition = (screen.width) ? (screen.width-w)/2 : 0;
TopPosition = (screen.height) ? (screen.height-h)/2 : 0;
settings =
'height='+h+',width='+w+',top='+TopPosition+',left='+LeftPosition+',scrollbars='+scroll+',resizable'
popupWindow = window.open(url,winName,settings)
}
</script>
</head>
<body>
<div style="position:absolute; top:8px; right:8px" >
<img onClick="window.location = '<?php echo $script;?>'" src="../images/refresh16.gif" alt="refresh" title="refresh" border="0">&nbsp;&nbsp;
<img onClick="centeredPopup('../help/help_logging.php','help','600','500','yes');return false" src="../images/help16.gif" alt="help" title="help" border="0">&nbsp;&nbsp;
<img onClick="window.location = '../assist.php'" src="../images/assist16.gif" alt="manager assist" title="manager assist" border="0">&nbsp;&nbsp;
<img onClick="window.location = '../index.php'" src="../images/home16.gif" alt="home" title="home" border="0">
</div>

<div style="position:absolute; top:30px; right:8px" ><strong>SoftPBX</strong>: 
<a href="Admin.php" alt="Admin" title="Admin">Admin</a>&nbsp;|&nbsp;
<a href="Voicemail.php" alt="Voicemail" title="Voicemail">Voicemail</a>


<?php

	if (file_exists('/SpliceCom/logs/vision.log'))
		echo "<br/><br/><strong>Vision</strong>: <a href='Vision.php' alt='Vision' title='Vision'>Vision</a>";
	if (file_exists('/SpliceCom/logs/calllog.log'))
		echo "&nbsp;|&nbsp;<a href='CallLog.php' alt='CallLog' title='CallLog'>CallLog</a>";
	if (file_exists('/SpliceCom/logs/callrecording.log'))
		echo "&nbsp;|&nbsp;<a href='CallRecording.php' alt='CallRecording' title='CallRecording'>CallRecording</a>";
	if (file_exists('/SpliceCom/logs/upcs.log'))
		echo "<br/><br/><strong>SSL-Gateway</strong>: <a href='SSL-Gateway.php' alt='upcs' title='upcs'>SSL-Gateway</a>";
	
	if ($manager_user == 'Manager' ) {
		echo "<br/><br/><strong>Apache2</strong>: <a href='apacheaccess.php' alt='access_log' title='access_log'>Access Log</a>&nbsp;|&nbsp;<a href='apacheerror.php' alt='error_log' title='error_log'>Error Log</a>";
	}

?>
</div>

<div style="position:absolute; top:20px; left:15px" >
<a href="index.php" alt="Debug" title="Debug">Debug Settings</a>&nbsp;|&nbsp;
<?php link_check("046","<a href='diskspace.php?p=1' alt='Disk Space' title='Disk Space' onclick=\"centeredPopup(this.href,'diskspace','950','550','yes');return false\">Disk Space</a>&nbsp;|&nbsp;", $ma_acl); ?>
<a href="reset.php?reset=1" alt="Reset" title="Reset">Reset Settings</a>&nbsp;|&nbsp;
<a href="<?php echo $script?>?clear=1" alt="Clear" title="Clear" onClick="return confirm('Clear all \'.wlog\' files from /SpliceCom/Web/download/ ?')">Clear Old Logs</a>
</div>

<div id="contain">
<h2><img src='../images/ok.png' style="vertical-align:middle;">&nbsp;Logging - View Live System Logs</h2>
<?php
$fh = fopen($reset, 'w') or die("can't open file - Please Click Reset Settings");
$script=basename($_SERVER['SCRIPT_NAME']);
$ds = ldap_connect("127.0.0.1",4000);
if ( ! $ds) {
    echo "LDAP connect failure<br>";
} else {
    $r = @ldap_bind($ds,"INTERNAL","0123456");
	if ( ! $r) {
	    echo "LDAP bind failure<br>";
		$ds = false;
	}
}
if (isset($_POST['cb'])) {
   if (isset($_POST['checkbox'])) $att=array ($_POST['cb'] => 1);
   else $att=array ($_POST['cb'] => 0);
}
if (isset($_POST['dr'])) {
	if (isset($_POST['dr'])) $att=array ($_POST['dr'] => $_POST['debug']);
 }
if (isset($att)) {
   ldap_modify($ds,$_POST['dn'],$att);
}
echo "This page allows you to set the debug and logging settings for this CallServer Module.<br/>";
if (substr(phpversion(),0,1)=="4") {
	echo "<br/>Once full logging is enabled you can view the Admin, Gateway, Voicemail and Phone Logs live via Telnet or your Web Browser<br/>and optionally capture this data to a new log file for downloading.<br/><br/>";
}else{
	echo "<br/>Once full logging is enabled you can view the Admin, and Voicemail Logs live via SSH or your Web Browser<br/>and optionally capture this data to a new log file for downloading.<br/><br/>";
}
echo "<b>Please Note:</b> Enabling logging can use additional system resources and could result in very large logs files.<br/>
      If you enable any of the logging options you <b>MUST</b> disable the options once you have concluded your logging.<br/>
      Failure to do so could result in large log files filling the disk, causing instability in the phone system.<br/>
      Viewing logs via the web browser also uses additional system resources.<br/><br/>";
?>
<div id="maincontainer">
<?php
if ($ds) {
    $sr = ldap_read($ds,"cn=self,cn=Modules","objectclass=*"); $info = ldap_get_entries($ds,$sr);
    $sr = ldap_search($ds,"cn=Modules","(&(objectclass=*)(guid=".$info[0]['location'][0]."))"); $info = ldap_get_entries($ds,$sr);
	$cn=$info[0]['cn'][0];$dn=$info[0]['dn'];
	$locn = $info[0]['guid'][0];
	?>
<div><h3><?php echo $cn ?></h3></div>
<div id="contentwrapper">
<div id="contentcolumn">
<div class="innertube"><div><h3>Voicemail</h3></div>
<?php
$types=array('traceconcurrency','traceimappoll','tracehttpstream');
			$text=array('Debug Concurrency ','Debug IMAP Poll ','Debug VXML Data ');
			$sr3=@ldap_search($ds,"cn=voicemailports","(&(objectclass=voicemailport)(location=$locn))"); $info3=ldap_get_entries($ds,$sr3);
            for($n3=0;$n3<$info3['count'];$n3++) {
            foreach ($types as $k => $v) {
			if ($info3[$n3][$v][0]) $checked="checked"; else $checked="";
            echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info3[$n3]['dn']."'/><input type='hidden' name='cb' value='".$v."'/>
			<b>".$info3[$n3]['cn'][0]."</b> - ".$text[$k]."<input name='checkbox' class='input' onClick=\"submit(); this.disabled=true\" type='checkbox' title='".$text[$k]."' $checked /></form></div>";
			$rst = $info3[$n3]['cn'][0].",".$info3[$n3]['dn'].";".$v.";0\r\n"; fwrite($fh, $rst);
			}


			echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info3[$n3]['dn']."'/><input type='hidden' name='dr' value='tracesmtp'/>
		  	<label><b>SMTP</b></label><select name='debug' class='input' onchange=\"submit(); this.disabled=true\"><option "; if($info3[$n3]['tracesmtp'][0]=="0") echo "selected"; echo " value='0'>Error Only</option>
			<option "; if($info3[$n3]['tracesmtp'][0]=="1") echo "selected"; echo " value='1'>Trace</option><option "; if($info3[$n3]['tracesmtp'][0]=="2") echo "selected"; echo " value='2'>Packets</option>
			</select></form></div>"; $rst = $info3[$n3]['cn'][0].",".$info3[$n3]['dn'].";tracesmtp;0\r\n"; fwrite($fh, $rst);

			echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info3[$n3]['dn']."'/><input type='hidden' name='dr' value='traceimap'/>
		  	<label><b>IMAP</b></label><select name='debug' class='input' onchange=\"submit(); this.disabled=true\"><option "; if($info3[$n3]['traceimap'][0]=="0") echo "selected"; echo " value='0'>Error Only</option>
			<option "; if($info3[$n3]['traceimap'][0]=="1") echo "selected"; echo " value='1'>Trace</option><option "; if($info3[$n3]['traceimap'][0]=="2") echo "selected"; echo " value='2'>Packets</option>
			</select></form><br/></div><br/>"; $rst = $info3[$n3]['cn'][0].",".$info3[$n3]['dn'].";traceimap;0\r\n"; fwrite($fh, $rst);
			}
			?>
</div>
</div>
</div>
<div id="leftcolumn">
<div class="innertube"><div><h3>Module</h3></div>
<?php
		if (substr(phpversion(),0,1)=="4") {
			$types=array('debugldap','debugdb','debuggatekeeper','debugsocket');
			$text=array('LDAP','Database','Gatekeeper','Socket');
				} else {
			$types=array('debugldap','debugdb','debuggatekeeper','debugsocket');
			$text=array('LDAP','Database','Gatekeeper','Socket');
				}
            $sr2=@ldap_search($ds,$dn,"objectclass=administrationmodule"); $info2=ldap_get_entries($ds,$sr2);
            for($n2=0;$n2<$info2['count'];$n2++) {

	     	foreach ($types as $k => $v) {
      		if ($info2[$n2][$v][0]) $checked="checked"; else $checked="";
            echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info2[$n2]['dn']."'/><input type='hidden' name='cb' value='".$v."'/>
			<label>Debug <b>".$text[$k]."</b></label><input name='checkbox' class='input' onClick=\"submit(); this.disabled=true\" type='checkbox' title='".$text[$k]."' $checked /></form></div>";
			$rst = $info2[$n2]['dn'].";".$v.";0\r\n"; fwrite($fh, $rst);
			}
		}
			echo "<br/>";
			echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info2[0]['dn']."'/><input type='hidden' name='dr' value='debugcalls'/>
		  	<label><b>Call Flow</b></label><select name='debug' class='input' onchange=\"submit(); this.disabled=true\"><option "; if($info2[0]['debugcalls'][0]=="0") echo "selected"; echo " value='0'>Basic</option>
			<option "; if($info2[0]['debugcalls'][0]=="1") echo "selected"; echo " value='1'>Normal</option><option "; if($info2[0]['debugcalls'][0]=="2") echo "selected"; echo " value='2'>Detail</option>
			<option "; if($info2[0]['debugcalls'][0]=="3") echo "selected"; echo " value='3'>Debug</option></select></form></div>"; $rst = $info2[0]['dn'].";debugcalls;0\r\n"; fwrite($fh, $rst);

			echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info2[0]['dn']."'/><input type='hidden' name='dr' value='debugsip'/>
		  	<label><b>Debug SIP</b></label><select name='debug' class='input' onchange=\"submit(); this.disabled=true\"><option "; if($info2[0]['debugsip'][0]=="0") echo "selected"; echo " value='0'>Basic</option>
			<option "; if($info2[0]['debugsip'][0]=="1") echo "selected"; echo " value='1'>Normal</option><option "; if($info2[0]['debugsip'][0]=="2") echo "selected"; echo " value='2'>Detail</option>
			<option "; if($info2[0]['debugsip'][0]=="3") echo "selected"; echo " value='3'>Debug</option></select></form></div>"; $rst = $info2[0]['dn'].";debugsip;0\r\n"; fwrite($fh, $rst);

			echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info2[0]['dn']."'/><input type='hidden' name='dr' value='debugras'/>
		  	<label><b>Debug RAS</b></label><select name='debug' class='input' onchange=\"submit(); this.disabled=true\"><option "; if($info2[0]['debugras'][0]=="0") echo "selected"; echo " value='0'>Error Only</option>
			<option "; if($info2[0]['debugras'][0]=="1") echo "selected"; echo " value='1'>Trace</option><option "; if($info2[0]['debugras'][0]=="2") echo "selected"; echo " value='2'>Packets</option>
			</select></form></div>"; $rst = $info2[0]['dn'].";debugras;0\r\n"; fwrite($fh, $rst);

			echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info2[0]['dn']."'/><input type='hidden' name='dr' value='debugh225'/>
		  	<label><b>Debug H225</b></label><select name='debug' class='input' onchange=\"submit(); this.disabled=true\"><option "; if($info2[0]['debugh225'][0]=="0") echo "selected"; echo " value='0'>Error Only</option>
			<option "; if($info2[0]['debugh225'][0]=="1") echo "selected"; echo " value='1'>Trace</option><option "; if($info2[0]['debugh225'][0]=="2") echo "selected"; echo " value='2'>Packets</option>
			</select></form></div>"; $rst = $info2[0]['dn'].";debugh225;0\r\n"; fwrite($fh, $rst);

			echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info2[0]['dn']."'/><input type='hidden' name='dr' value='debugh245'/>
		  	<label><b>Debug H245</b></label><select name='debug' class='input' onchange=\"submit(); this.disabled=true\"><option "; if($info2[0]['debugh245'][0]=="0") echo "selected"; echo " value='0'>Error Only</option>
			<option "; if($info2[0]['debugh245'][0]=="1") echo "selected"; echo " value='1'>Trace</option><option "; if($info2[0]['debugh245'][0]=="2") echo "selected"; echo " value='2'>Packets</option>
			</select></form></div>"; $rst = $info2[0]['dn'].";debugh245;0\r\n"; fwrite($fh, $rst);

			echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info2[0]['dn']."'/><input type='hidden' name='dr' value='debugh450'/>
		  	<label><b>Debug H450</b></label><select name='debug' class='input' onchange=\"submit(); this.disabled=true\"><option "; if($info2[0]['debugh450'][0]=="0") echo "selected"; echo " value='0'>Error Only</option>
			<option "; if($info2[0]['debugh450'][0]=="1") echo "selected"; echo " value='1'>Trace</option><option "; if($info2[0]['debugh450'][0]=="2") echo "selected"; echo " value='2'>Packets</option>
			</select></form></div>"; $rst = $info2[0]['dn'].";debugh450;0\r\n"; fwrite($fh, $rst);
?>
</div>
</div>
<div id="rightcolumn">
<div class="innertube">
<?php
if (substr(phpversion(),0,1)=="4") {
			echo "<div><h3>Trunks</h3></div>";
			$types=array('tracelayer2','tracelayer3');	$text=array('Trace Layer 2 ','Trace Layer 3 ');
			$sr3=@ldap_list($ds,$dn,"(&(&(objectclass=trunk)(location=$locn)(typeoftrunk<=1)))"); $info3=ldap_get_entries($ds,$sr3);
            for($n3=0;$n3<$info3['count'];$n3++) {
	        echo "<b>".$info3[$n3]['cn'][0]."</b><br/>" ;
	        foreach ($types as $k => $v) {
      		if ($info3[$n3][$v][0]) $checked="checked"; else $checked="";
			echo "<div class='block'><form name=form method=post action=$script><input type='hidden' name='dn' value='".$info3[$n3]['dn']."'/><input type='hidden' name='cb' value='".$v."'/><label>".
			$text[$k]."</label><input name='checkbox' class='input' onClick=\"submit(); this.disabled=true\" type='checkbox' title='".$text[$k]."' $checked /></form></div>";
			$rst = $info3[$n3]['dn'].";".$v.";0\r\n"; fwrite($fh, $rst);
			}
		  }
	  }
?>
</div>
</div>
</div>
<?php
}
?>
<div class="overlay" id="overlay" style="display:none;"></div>
        <div class="alert" id="alert">
            <a class="alertclose" id="alertclose"></a>
			<a class="alertOK" id="alertOK"></a>
            <h1>Warning</h1>
            <p>
            Enabling logging can use additional system resources and could result in very large logs files.<br/><br/>
            If you enable any of the logging options you <span style="color:red; font-weight:bold";>MUST</span> disable the options once you have concluded your logging.&nbsp;
           	Failure to do so could result in large log files filling the disk, causing instability in the phone system.<br/><br/>
            <strong>Please Note:</strong> viewing logs via the web browser also uses additional system resources.<br/><br/>
      		Please select the <span style="color:#329C24; font-weight:bold";>Green Tick</span> to proceed, otherwise select the  <span style="color:#605F61; font-weight:bold";>Grey X</span> to return to Manager Assist.</p>
            </p>
        </div>
        <?php
        if (!isset($_SESSION['alert'])) {
	    ?>
        <script type="text/javascript" src="jquery-1.8.0.min.js"></script>
        <script type="text/javascript">
            $(function() {
                    $('#overlay').fadeIn('fast',function(){
                        $('#alert').animate({'top':'100px'},500);
                      });
                $('#alertclose').click(function(){
                	   	$('#alert').animate({'top':'-600px'},500,function(){
                        $('#overlay').fadeOut('fast');
                        document.location.href='../assist.php';
                    });
                });
            	$('#alertOK').click(function(){
	        		$.ajax({ url : 'reset.php?alert=1' });
            		$('#alert').animate({'top':'-600px'},500,function(){
            		$('#overlay').fadeOut('fast');
            	});
          });
            });
        </script>
        <?php
    	}
        ?>
</div>
</body>
</html>
